
/*===============================<o>=====================================

  This software was written by Ian L. Kaplan, Chief Fat Bear, Bear Products
  International.  Use of this software, for any purpose, is granted on two
  conditions: 

   1. This copyright notice must be included with the software
      or any software derived from it.

   2. The risk of using this software is accepted by the user.  No
      warranty as to its usefulness or functionality is provided
      or implied.  The author and Bear Products International provides
      no support.

   May 1996

 ===============================<o>=====================================*/

#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <string.h>
#include "ianstd.h"
#include "sier.h"
#include "commline.h"


void commline::usage(void) 
{ 
  printf("\n%s creates a Sierpinski pyramid, which it writes out\n", 
	 program_name);
  printf("as a DXF file and displays in an openGL window.\n\n");
  printf("    usage: %s <power> [ -o <file name> ]\n\n", program_name ); 
  printf("The <power> argument controls the size of the pyramid.\n");
  printf("A single pyramid is power 0, a pyramid supported by four\n");
  printf("child pyramids is power 1.  A power one pyramid supported\n");
  printf("by four power 1 children is power 2.  A power N-1 pyramid\n");
  printf("supported by four N-1 pyramids is power N\n");
  printf("\nThe file name argument is optional.  If it is ommitted,\n");
  printf("the DXF information will be written to stdout.\n");
}

//
// commline class functions for processing command line arguments.
// The command line is:
//
//   <program> <power> [ -o filename ]


commline::ArgStatus commline::get_power_arg( char *power_str )
{
  ArgStatus status;

  status = BadArgs;
  if (power_str != NULL && power_str[0] != '\0') {
    int i;
    int badarg = FALSE;

    status = ArgsOK;
    for (i = 0; i < (int)strlen(power_str); i++) {
      if (! isdigit(power_str[ i ])) {
	status = BadArgs;
	break;
      }
    }
    if (status == ArgsOK) {
      pyr_power = atoi(power_str);
      if (pyr_power > Sierpinski_types::MaxPower) {
	usage();
	printf("<power> must be less than or equal to %d\n",  
	       Sierpinski_types::MaxPower);
	status = BadArgs;
      }
    }
    else 
      usage();
  }
  return status;
}  // get_power_arg



//
// commline constructor
//
commline::commline( int argc, char *argv[] )
{
  typedef enum { ProgramName = 0, PyrPower = 1, 
		 MinusOh = 2, FileName = 3 } bogus;

  program_name = argv[ ProgramName ];

  filename = NULL;
  if (argc >= 2) {
    status = get_power_arg( argv[ PyrPower ] );
    if (status == ArgsOK) {
      if (argc == ((int)FileName+1)) {
	if (strcmp(argv[ MinusOh ], "-o") == 0)
	  filename = argv[ FileName ];
	else
	  usage();
      }
    }
  }
  else {
    usage();
  }
} // commline
